==> sleepyemoji-2.7-py3-none-any.whl: toolchain/emojis.py <==
'''
<category> = [
  ['<emoji>', '<discord-value>', '<ios-descriptor>'],
]
'''
faces = [
  ["🙂", ":slight_smile:", "slightly smiling face"],
  ["🙃", ":upside_down:", "upside down face"],
  ["😊", ":blush:", "smiling face with smiling eyes"],
  ["😆", ":laughing:", "grinning squinting face"],
  ["😉", ":wink:", "winking face"],
  ["😏", ":smirk:", "smirking face"],
  ["😅", ":sweat_smile:", "grinning face with sweat"],
  ["🥺", ":pleading_face:", "pleading face"],
  ["😇", ":innocent:", "smiling face with halo"],
  ["😐", ":neutral_face:", "neutral face"],
  ["😑", ":expressionless:", "expressionless face"],
  ["🥳", ":partying face:", "party face"],
  ["😴", ":sleeping:", "sleeping face"],
  ["🥵", ":hot_face:", "hot face"],
  ["🤯", "exploding_head", "exploding head"],
  ["🤓", ":nerd:", "smiling face with glasses"],
  ["😭", ":sob:", "loudly crying face"],
  ["🫠 ", ":melting_face:", "melting face"],
  ["🤣", ":rofl:", "rolling on the floor laughing face"],
  ["😤", ":triumph:", "face with steam from nose"],
  ["😈", ":smiling_imp:", "smiling face with horns"],
  ["👀", ":eyes:", "eyes"],
]
animals = [
  ["🦦", ":otter:", "otter"],
  ["🙀", ":scream_cat:", "cat face screaming in fear"],
  ["🐶", ":dog:", "dog face"],
]
hands = [
  ["👌", ":ok_hand:", "ok hand sign"],
  ["👍", ":thumbsup:", "thumbs up"],
  ["✌ ", ":v:", "peace sign hand"],
  ["👎", ":thumbsdown:", "thumbs down"],
  ["👏", ":clap:", "clapping hands"],
  ["👈", ":point_left:", "backhand index finger pointing left"],
  ["👉", ":point_right:", "bakchand index finger pointing right"],
  ["👆", ":point_up:", "bakchand index finger pointing up"],
  ["👇", ":point_down:", "bakchand index finger pointing down"],
  ["🙌", ":raised_hands:", "hands raised in celebration"],
  ["💪", ":muscle:", "flexed bicep"],
]
icons = [
  ["🔥", ":fire:", "fire"],
  ["❌", ":x:", "cross mark"],
  ["✅", ":white_check_mark:", "check mark symbol"],
  ["🚩", ":triangular_flag_on_post:", "triangular flag on post"],
  ["📄", ":page_facing_up:", "page facing up"],
  ["⚠ ", ":warning:", "warning"],
  ["💙", ":blue_heart:", "blue heart"],
  ["💜", ":purple_heart:", "purple heart"],
  ["💕", ":two_hearts:", "two hearts"],
  ["🍆", ":eggplant:", "eggplant"],
  ["🍑", ":peach:", "peach"],
  ["💦", ":sweat_drops:", "water droplets"],
  ["✨", ":sparkles:", "sparkles"],
  ["🚧", ":construction:", "construction sign"],
  ["❗", ":exclamation:", "red exclamation mark"],
  ["❓", ":question:", "red question mark"],
  ["™️", ":tm:", "trade mark sign"],
  ["📁", ":file_folder:", "closed file folder"],
  ["🎉", ":tada:", "party popper"],
]
people = [
  "🤷",
  [":person_shrugging", "person shrugging"],
  "💃",
  [":dancer:", "woman dancing"],
]


'''
combos = [
  ['<emojis>', '', ''],
]
'''
combos = [
  ["👁👄👁", "", ""],
  ["☕🤏", "", ""],
  ["😐🕶🤏", "", ""],
  ["🎊🥳🎉", "", ""],
  ["🌮🔔", "", ""],
  ["🍆💦🍑", "", ""],
  ["🍆💦👅", "", ""],
  ["👋🍑😫", "", ""],
  ["👉👌🥵", "", ""],
  ["🔥🚒👩‍🚒", "", ""],
  ["💅✨", "", ""],
]

==> sleepyemoji-3.7-py3-none-any.whl: toolchain/emojis.py <==
'''
<category> = [
  ['<emoji>', '<discord-value>', '<ios-descriptor>'],
]
'''
faces = [
  ["🙂", ":slight_smile:", "slightly smiling face"],
  ["🙃", ":upside_down:", "upside down face"],
  ["😊", ":blush:", "smiling face with smiling eyes"],
  ["😆", ":laughing:", "grinning squinting face"],
  ["😉", ":wink:", "winking face"],
  ["😏", ":smirk:", "smirking face"],
  ["😅", ":sweat_smile:", "grinning face with sweat"],
  ["🥺", ":pleading_face:", "pleading face"],
  ["😇", ":innocent:", "smiling face with halo"],
  ["😐", ":neutral_face:", "neutral face"],
  ["😑", ":expressionless:", "expressionless face"],
  ["🥳", ":partying face:", "party face"],
  ["😴", ":sleeping:", "sleeping face"],
  ["🥵", ":hot_face:", "hot face"],
  ["🤯", "exploding_head", "exploding head"],
  ["🤓", ":nerd:", "smiling face with glasses"],
  ["😭", ":sob:", "loudly crying face"],
  ["🫠 ", ":melting_face:", "melting face"],
  ["🤣", ":rofl:", "rolling on the floor laughing face"],
  ["😤", ":triumph:", "face with steam from nose"],
  ["😈", ":smiling_imp:", "smiling face with horns"],
  ["👀", ":eyes:", "eyes"],
]
animals = [
  ["🦦", ":otter:", "otter"],
  ["🙀", ":scream_cat:", "cat face screaming in fear"],
  ["🐶", ":dog:", "dog face"],
]
hands = [
  ["👌", ":ok_hand:", "ok hand sign"],
  ["👍", ":thumbsup:", "thumbs up"],
  ["✌ ", ":v:", "peace sign hand"],
  ["👎", ":thumbsdown:", "thumbs down"],
  ["👏", ":clap:", "clapping hands"],
  ["👈", ":point_left:", "backhand index finger pointing left"],
  ["👉", ":point_right:", "bakchand index finger pointing right"],
  ["👆", ":point_up:", "bakchand index finger pointing up"],
  ["👇", ":point_down:", "bakchand index finger pointing down"],
  ["🙌", ":raised_hands:", "hands raised in celebration"],
  ["💪", ":muscle:", "flexed bicep"],
]
icons = [
  ["🔥", ":fire:", "fire"],
  ["❌", ":x:", "cross mark"],
  ["✅", ":white_check_mark:", "check mark symbol"],
  ["🚩", ":triangular_flag_on_post:", "triangular flag on post"],
  ["📄", ":page_facing_up:", "page facing up"],
  ["⚠ ", ":warning:", "warning"],
  ["💙", ":blue_heart:", "blue heart"],
  ["💜", ":purple_heart:", "purple heart"],
  ["💕", ":two_hearts:", "two hearts"],
  ["🍆", ":eggplant:", "eggplant"],
  ["🍑", ":peach:", "peach"],
  ["💦", ":sweat_drops:", "water droplets"],
  ["✨", ":sparkles:", "sparkles"],
  ["🚧", ":construction:", "construction sign"],
  ["❗", ":exclamation:", "red exclamation mark"],
  ["❓", ":question:", "red question mark"],
  ["™️", ":tm:", "trade mark sign"],
  ["📁", ":file_folder:", "closed file folder"],
  ["🎉", ":tada:", "party popper"],
]
people = [
  ["🤷", ":person_shrugging", "person shrugging"],
  ["💃", ":dancer:", "woman dancing"],
]


'''
combos = [
  ['<emojis>', '', ''],
]
'''
combos = [
  ["👁👄👁", "", ""],
  ["☕🤏", "", ""],
  ["😐🕶🤏", "", ""],
  ["🎊🥳🎉", "", ""],
  ["🌮🔔", "", ""],
  ["🍆💦🍑", "", ""],
  ["🍆💦👅", "", ""],
  ["👋🍑😫", "", ""],
  ["👉👌🥵", "", ""],
  ["🔥🚒👩‍🚒", "", ""],
  ["💅✨", "", ""],
]
